

#define corrfct  corrfctvalue


double corrfct(double, double, double, int);

